@@ -29,7 +29,7 @@ DataTree    = join(SourceTree, "data")
 SB_Dir      = join(SourceTree, "sourcebuild")
 ModuleDir   = join(SourceTree, "src", "pypdfium2")
 VersionFile = join(ModuleDir, "version.py")
-Changelog   = join(SourceTree, "docs", "source", "changelog.md")
+Changelog   = join(SourceTree, "docs", "devel", "changelog.md")
 ChangelogStaging = join(SourceTree, "docs", "devel", "changelog_staging.md")
 RepositoryURL  = "https://github.com/pypdfium2-team/pypdfium2"
 PDFium_URL     = "https://pdfium.googlesource.com/pdfium"
@@ -45,6 +45,8 @@ class SystemNames:
 
 
 class PlatformNames:
+    # - Attribute names and values are expected to match
+    # - Platform names are expected to start with the corresponding system name
     linux_x64      = SystemNames.linux   + "_x64"
     linux_x86      = SystemNames.linux   + "_x86"
     linux_arm64    = SystemNames.linux   + "_arm64"
@@ -264,6 +266,22 @@ def copy_platfiles(pl_name):
         shutil.copy(fp, ModuleDir)
 
 
+def get_changelog_staging(flush=False):
+    
+    with open(ChangelogStaging, "r") as fh:
+        content = fh.read()
+        pos = content.index("\n", content.index("# Changelog")) + 1
+        header = content[:pos].strip() + "\n"
+        devel_msg = content[pos:].strip()
+        if devel_msg:
+            devel_msg += "\n"
+    
+    if flush:
+        with open(ChangelogStaging, "w") as fh:
+            fh.write(header)
+    
+    return devel_msg
+
 def get_version_ns():
     ver_ns = {}
     with open(VersionFile, "r") as fh:
@@ -291,7 +309,8 @@ def set_versions(ver_changes):
         if var in skip:
             continue
         
-        # Assuming previous and new value are of the same type
+        # this does not work universally - only one notation per type is supported, and switches between str and non-str types don't work
+        # FIXME see if we can restructure this code for improved flexibility
         if isinstance(new_val, str):
             template = '%s = "%s"'
         else:
@@ -303,7 +322,7 @@ def set_versions(ver_changes):
         assert content.count(previous) == 1
         content = content.replace(previous, updated)
         
-        # Beware: While this updates the VerNamespace entry itself, it will not update dependent entries, which may lead to inconsistent data. That is, no reliance can be placed upon the value of `V_PYPDFIUM2` after this method has been run. If you need the real value, VerNamespace needs to be re-created.
+        # Beware: While this updates the VerNamespace entry itself, it will not update dependent entries, which may lead to inconsistent data. That is, no reliance can be placed upon the values of dynamic variables (V_PYPDFIUM2 !) after this method has been run. If you need the real value, VerNamespace needs to be re-created.
         VerNamespace[var] = new_val
     
     with open(VersionFile, "w") as fh:
